<?php
/**
 * The header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content">
 *
 * @package topcat
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
	<!--[if lt IE 9]>
	<script src="<?php echo esc_url( get_template_directory_uri() ); ?>/js/html5.js"></script>
	<![endif]-->

	<?php
	/* Backward compatible code for wp_title */
	if ( ! function_exists( '_wp_render_title_tag' ) ) {
		function topcat_render_title() {
			?>
			<title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
		}

		add_action( 'wp_head', 'topcat_render_title' );
	}
	?>

	<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
<div id="page" class="hfeed site topcat_page">
	<a class="skip-link screen-reader-text" href="#content"><?php _e( 'Skip to content', 'topcat' ); ?></a>
	<header id="masthead" class="site-header  clear" role="banner">
		<div class="site-description">
			<?php if ( get_header_image() ) { ?>

				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><img src="<?php header_image(); ?>"
				                                                                    width="<?php echo esc_attr( get_custom_header()->width ); ?>"
				                                                                    height="<?php echo esc_attr( get_custom_header()->height ); ?>"
				                                                                    alt=""></a>
			<?php } else {
				?>
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><img src="<?php
					echo( get_template_directory_uri() . '/images/logo.png' ); ?>"
				                                                                    width="<?php echo esc_attr( get_custom_header()->width ); ?>"
				                                                                    height="<?php echo esc_attr( get_custom_header()->height ); ?>"
				                                                                    alt=""></a>
			<?php
			}
			?>
		</div>
		<?php topcat_social_menu(); ?>

		<nav id="site-navigation" class="clear" role="navigation">
			<div class="menu-toggle clear">
				<div class="menu_blogname"><?php bloginfo( 'name' ); ?></div>
				<div class="menu_htmlchar"><?php _e( '<a href="#menu">&#9776;</a>', 'topcat' ); ?></div>
			</div>
			<a class="skip-link screen-reader-text" href="#content"><?php _e( 'Skip to content', 'topcat' ); ?></a>
		</nav>
		<div class="main-navigation">
			<?php
			if ( has_nav_menu( 'primary' ) ) {
				wp_nav_menu( array(
					'theme_location'  => 'primary',
					'menu_class'      => 'nav-menu',
					'container_class' => 'nav-container',
					'container'       => 'div'
				) );
			} else {
				wp_nav_menu( array( 'theme_location' => 'primary', 'menu_class' => 'nav-container' ) );
			}
			?>
		</div>
	</header>
	<div id="content" class="site-content">